#!/usr/bin/perl
use warnings;
use strict;

my $PREFIX_NAMES_FILENAME = 'prefix-names.txt';
my $PREFIX_RANGES_FILENAME = 'prefix-ranges.txt';

print <<EOF;
-- This file was automatically generated with '$0'
-- using data from the files '$PREFIX_NAMES_FILENAME' and
-- '$PREFIX_RANGES_FILENAME'.

local M = { _NAME = "isbn._data" }

M.country_name = {
EOF

my %prefix_name;
{
    open my $fh, '<', $PREFIX_NAMES_FILENAME
        or die "$0: error opening '$PREFIX_NAMES_FILENAME': $!\n";
    while (<$fh>) {
        chomp;
        /^(\d+)\s+([^"]+)$/ or die "$PREFIX_NAMES_FILENAME:$.: bad line\n";
        $prefix_name{$1} = $2;
        print "    [\"$1\"]=\"$2\",\n";
    }
}

my %new_hash;

open my $fh, '<', $PREFIX_RANGES_FILENAME
    or die "$0: error opening '$PREFIX_RANGES_FILENAME': $!\n";
my $max_country_code_length = 0;
while (<$fh>) {
    chomp;
    my ($country, $first, $second) = split ' ';

    die "Code $country does not have name listed in '$PREFIX_NAMES_FILENAME'\n"
        unless exists $prefix_name{$country};

    $max_country_code_length = length($country)
        if length($country) > $max_country_code_length;

    push @{$new_hash{$country}}, [ $first, $second ];
}

print <<EOF;
}

M.country_ranges = {
EOF

foreach my $key (sort { $a <=> $b } keys %new_hash) {
    my $array = $new_hash{$key};

    my @pairs = map { "\"$_->[0]\",\"$_->[1]\"" } @$array;
    my $pairs = join ", ", @pairs;

    print "    [\"$key\"]={ $pairs },\n";
}

print <<EOF;
}

M.max_country_code_length = $max_country_code_length

return M
EOF

# vi:ts=4 sw=4 expandtab
